@@ -1,4 +1,6 @@
-from .iosxr import SCIOSXR
+# from .iosxr_netconf import SCIOSXR
+from .iosxr import SCIOSXR_SSH
+from .iosxr_netconf import SCIOSXR
 from .junos import SCJunOS
 from .nxos import SCNXOS
 from .sros import SCNokiaSROSDriver
@@ -6,9 +8,13 @@ from .srl_ssh import NokiaSRLSSHDriver
 from .srl import SCNokiaSRLDriver
 from .eos import SCEOSDriver
 from .nos import SCNOSDriver
+from .aoscx import SCAOSCXDriver
+from .waveserver import WaveServerDriver
+from .psimn import PSIMN
 
 PLATFORM_MAP = {
-    "iosxr": SCIOSXR,
+    "iosxr": SCIOSXR_SSH,
+    "iosxr_netconf": SCIOSXR,
     "nxos": SCNXOS,
     "junos": SCJunOS,
     "sros": SCNokiaSROSDriver,
@@ -16,6 +22,9 @@ PLATFORM_MAP = {
     "srl": SCNokiaSRLDriver,
     "eos": SCEOSDriver,
     "nos": SCNOSDriver,
+    "waveserver": WaveServerDriver,
+    "aoscx": SCAOSCXDriver,
+    "psimn": PSIMN,
 }
 
 
